# airtouch2_python
In-development Python client for the Polyaire AirTouch 2 airconditioning system

## Thanks to
https://github.com/tonymyatt/airtouch3api

https://github.com/ozczecho/vzduch-dotek

https://community.home-assistant.io/t/polyaire-air-touch-2-or-3/19650/44
